@@ -26,13 +26,17 @@ def cache(
             nonlocal coder
             nonlocal expire
             nonlocal key_builder
+            request = kwargs.get("request")
+            if request.headers.get("Cache-Control") == "no-store":
+                return await func(*args, **kwargs)
 
             coder = coder or FastAPICache.get_coder()
             expire = expire or FastAPICache.get_expire()
             key_builder = key_builder or FastAPICache.get_key_builder()
-            request = kwargs.get("request")
+            request = kwargs.pop("request", None)
+            response = kwargs.pop("response", None)
             backend = FastAPICache.get_backend()
-            cache_key = key_builder(func, namespace, *args, **kwargs)
+            cache_key = key_builder(func, namespace, args=args, kwargs=kwargs)
             ttl, ret = await backend.get_with_ttl(cache_key)
             if not request:
                 if ret is not None:
